import { IExplanationMap } from "@zowe/imperative";
import { IPromptVariable } from "./IPromptVariable";
/**
 * The ListTemplateInfo z/OSMF API response.
 * @export
 * @interface IPublishedTemplateInfo
 */
export interface IPublishedTemplateInfo {
    /**
     * Name of the template.
     * @type {string}
     * @memberof IPublishedTemplateInfo
     */
    name: string;
    /**
     * Version of the template.
     * @type {string}
     * @memberof IPublishedTemplateInfo
     */
    version: string;
    /**
     * Template owner ID.
     * @type {string}
     * @memberof IPublishedTemplateInfo
     */
    owner: string;
    /**
     * Status of the template.
     * @type {string}
     * @memberof IPublishedTemplateInfo
     */
    state: string;
    /**
     * Description of the template.
     * @type {string}
     * @memberof IPublishedTemplateInfo
     */
    description: string;
    /**
     * Generated name for a template.
     * @type {string}
     * @memberof IPublishedTemplateInfo
     */
    "generated-name": string;
    /**
     * The ID that identifies a template.
     * @type {string}
     * @memberof IPublishedTemplateInfo
     */
    "object-id": string;
    /**
     * The domain the template is associated with.
     * @type {string}
     * @memberof IPublishedTemplateInfo
     */
    "domain-name": string;
    /**
     * Name of the software that is being provisioned.
     * @type {string}
     * @memberof IPublishedTemplateInfo
     */
    "software-name": string;
    /**
     * Array the of prompt variables of the template.
     * @type {IPromptVariable}
     * @memberof IPublishedTemplateInfo
     */
    "prompt-variables": IPromptVariable[];
}
/**
 * Main explanation map object for summary output
 * @type {IExplanationMap}
 * @memberof IPublishedTemplateInfo
 */
export declare const explainPublishedTemplateInfoSummary: IExplanationMap;
/**
 * Main explanation map object for full output
 * @type {IExplanationMap}
 * @memberof IPublishedTemplateInfo
 */
export declare const explainPublishedTemplateInfoFull: IExplanationMap;
