import { AbstractSession } from "@zowe/imperative";
import { IJob } from "./doc/response/IJob";
import { IDeleteJobParms } from "./doc/input/IDeleteJobParms";
/**
 * Class to handle deletion of job information
 * @export
 * @class DeleteJobs
 */
export declare class DeleteJobs {
    /**
     * Cancel and purge a job
     * @static
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {string} jobname - job name to be translated into parms object
     * @param {string} jobid - job id to be translated into parms object
     * @returns {Promise<void>} - promise that resolves when the API call is complete
     * @memberof DeleteJobs
     */
    static deleteJob(session: AbstractSession, jobname: string, jobid: string): Promise<void>;
    /**
     * Cancel and purge a job
     * Alternative version of the delete API accepting an IJob object returned from other APIs such as GetJobs and SubmitJobs
     * @static
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {IJob} job - the job that you want to delete
     * @param {"1.0"| "2.0"} modifyVersion - version of the X-IBM-Job-Modify-Version header to use (see ZosmfHeaders)
     * @returns {Promise<void>} -  promise that resolves when the API call is completel
     * @memberof DeleteJobs
     */
    static deleteJobForJob(session: AbstractSession, job: IJob, modifyVersion?: "1.0" | "2.0"): Promise<void>;
    /**
     * Cancel and purge a job
     * Full version of the API with a parameter object
     * @static
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {IDeleteJobParms} parms - parm object (see IDeleteJobParms interface for details)
     * @returns {Promise<void>} - promise that resolves when the API call is complete
     * @memberof DeleteJobs
     */
    static deleteJobCommon(session: AbstractSession, parms: IDeleteJobParms): Promise<void>;
    /**
     * Getter for brightside logger
     * @returns {Logger}
     */
    private static get log();
}
