"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const imperative_1 = require("@zowe/imperative");
const vscode = require("vscode");
exports.ISTHEIA = false; // set during activate
exports.FAV_SUFFIX = "_fav";
exports.INFORMATION_CONTEXT = "information";
exports.FAVORITE_CONTEXT = "favorite";
exports.DS_FAV_CONTEXT = "ds_fav";
exports.PDS_FAV_CONTEXT = "pds_fav";
exports.DS_SESSION_CONTEXT = "session";
exports.DS_PDS_CONTEXT = "pds";
exports.DS_DS_CONTEXT = "ds";
exports.DS_MEMBER_CONTEXT = "member";
exports.DS_TEXT_FILE_CONTEXT = "textFile";
exports.DS_FAV_TEXT_FILE_CONTEXT = "textFile_fav";
exports.DS_BINARY_FILE_CONTEXT = "binaryFile";
exports.DS_MIGRATED_FILE_CONTEXT = "migr";
exports.USS_SESSION_CONTEXT = "uss_session";
exports.USS_DIR_CONTEXT = "directory";
exports.USS_FAV_DIR_CONTEXT = "directory_fav";
exports.JOBS_SESSION_CONTEXT = "server";
exports.JOBS_JOB_CONTEXT = "job";
exports.JOBS_SPOOL_CONTEXT = "spool";
exports.ICON_STATE_OPEN = "open";
exports.ICON_STATE_CLOSED = "closed";
exports.THEIA = "Eclipse Theia";
/**
 * Defines all global variables
 * @param tempPath File path for temporary folder defined in preferences
 */
function defineGlobals(tempPath) {
    // Set app name
    const appName = vscode.env.appName;
    if (appName && appName === this.THEIA) {
        this.ISTHEIA = true;
    }
    // Set temp path & folder paths
    tempPath !== "" && tempPath !== undefined ?
        exports.ZOWETEMPFOLDER = path.join(tempPath, "temp") :
        exports.ZOWETEMPFOLDER = path.join(__dirname, "..", "..", "resources", "temp");
    exports.ZOWE_TMP_FOLDER = path.join(exports.ZOWETEMPFOLDER, "tmp");
    exports.USS_DIR = path.join(exports.ZOWETEMPFOLDER, "_U_");
    exports.DS_DIR = path.join(exports.ZOWETEMPFOLDER, "_D_");
}
exports.defineGlobals = defineGlobals;
/**
 * Initializes Imperative Logger
 * @param context The extension context
 */
function initLogger(context) {
    const loggerConfig = require(path.join(context.extensionPath, "log4jsconfig.json"));
    loggerConfig.log4jsConfig.appenders.default.filename = path.join(context.extensionPath, "logs", "imperative.log");
    loggerConfig.log4jsConfig.appenders.imperative.filename = path.join(context.extensionPath, "logs", "imperative.log");
    loggerConfig.log4jsConfig.appenders.app.filename = path.join(context.extensionPath, "logs", "zowe.log");
    imperative_1.Logger.initLogger(loggerConfig);
    this.LOG = imperative_1.Logger.getAppLogger();
}
exports.initLogger = initLogger;

//# sourceMappingURL=globals.js.map
