"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const globals = require("./globals");
const os = require("os");
const path = require("path");
const Profiles_1 = require("./Profiles");
const imperative_1 = require("@zowe/imperative");
const nls = require("vscode-nls");
const localize = nls.config({ messageFormat: nls.MessageFormat.file })(__filename);
/*************************************************************************************************************
 * Error Handling
 * @param {errorDetails} error.mDetails
 * @param {label} - additional information such as profile name, credentials, messageID etc
 * @param {moreInfo} - additional/customized error messages
 *************************************************************************************************************/
function errorHandling(errorDetails, label, moreInfo) {
    let httpErrCode = null;
    const errMsg = localize(0, null) +
        `\n${label}\n` + localize(1, null);
    if (errorDetails.mDetails !== undefined) {
        httpErrCode = errorDetails.mDetails.errorCode;
    }
    switch (httpErrCode) {
        // tslint:disable-next-line: no-magic-numbers
        case 401:
            if (label.includes("[")) {
                label = label.substring(0, label.indexOf(" ["));
            }
            if (globals.ISTHEIA) {
                vscode.window.showErrorMessage(errMsg);
                Profiles_1.Profiles.getInstance().promptCredentials(label.trim());
            }
            else {
                vscode.window.showErrorMessage(errMsg, "Check Credentials").then((selection) => {
                    if (selection) {
                        Profiles_1.Profiles.getInstance().promptCredentials(label.trim(), true);
                    }
                });
            }
            break;
        default:
            vscode.window.showErrorMessage(moreInfo + " " + errorDetails);
            break;
    }
    return;
}
exports.errorHandling = errorHandling;
function resolveQuickPickHelper(quickpick) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((c) => quickpick.onDidAccept(() => c(quickpick.activeItems[0])));
    });
}
exports.resolveQuickPickHelper = resolveQuickPickHelper;
// tslint:disable-next-line: max-classes-per-file
class FilterItem {
    constructor(text, desc) {
        this.text = text;
        this.desc = desc;
    }
    get label() { return this.text; }
    get description() { if (this.desc) {
        return this.desc;
    }
    else {
        return "";
    } }
    get alwaysShow() { return false; }
}
exports.FilterItem = FilterItem;
// tslint:disable-next-line: max-classes-per-file
class FilterDescriptor {
    constructor(text) {
        this.text = text;
    }
    get label() { return this.text; }
    get description() { return ""; }
    get alwaysShow() { return true; }
}
exports.FilterDescriptor = FilterDescriptor;
/**
 * Function to retrieve the home directory. In the situation Imperative has
 * not initialized it we mock a default value.
 */
function getZoweDir() {
    imperative_1.ImperativeConfig.instance.loadedConfig = {
        defaultHome: path.join(os.homedir(), ".zowe"),
        envVariablePrefix: "ZOWE"
    };
    return imperative_1.ImperativeConfig.instance.cliHome;
}
exports.getZoweDir = getZoweDir;

//# sourceMappingURL=utils.js.map
